Type: Package
Title: Decomposition of Growth Trends
Version: 0.1.0
Description: Decomposes observed growth in agricultural and livestock systems into interpretable component effects. Depending on the application, the total change in output can be attributed to components such as area effect, yield effect, herd or slaughter effect, productivity effect, and interaction effect. Details can be found in Rakshit and Bardhan (2026) <doi:10.1007/s11250-026-04988-w>.
Author: Debopam Rakshit [aut, cre], Dwaipayan Bardhan [aut]
Maintainer: Debopam Rakshit <rakshitdebopam@yahoo.com>
Imports: fracdiff
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-17 18:21:47 UTC; Debopam
Repository: CRAN
Date/Publication: 2026-03-26 09:50:08 UTC

Decomposition of Growth Trends

Description

Decomposition of Growth Trends

Usage

decompose_growth(p, a, y)

Arguments

p

Production data

a

Area/Slaughter data

y

Yield/Productivity data

Value

Component effects and percent contribution

References

Rakshit, D., & Bardhan, D. (2026). How has India’s meat production evolved over the last twenty-five years, and what can we expect in the near future? Tropical Animal Health and Production, 58, Article 176. https://doi.org/10.1007/s11250-026-04988-w

Examples

p <- c(100, 120, 155)
a <- c(50, 55, 60)
y <- c(2.0, 2.18, 2.58)
dgt <- decompose_growth(p, a, y)

mirror server hosted at Truenetwork, Russian Federation.